package filters;

import org.xml.sax.helpers.XMLFilterImpl;
import org.xml.sax.Attributes;
import org.xml.sax.SAXException;

// A filter that filters a specific element or an
// element/attribute combination

public class ElementFilter extends XMLFilterImpl {
   private String filterThisElement,
                  filterThisAttribute;

   private boolean filtering; // A flag that tracks filtering state

   public ElementFilter() {
      // The element and attribute are unspecified when the filter
      // is created, and the filtering flag is set to false
      filterThisElement = filterThisAttribute = null;
      filtering  = false;
   }
   public void setElementToFilter(String filterThis) {
      int position;

      // If there's a at-sign in the filterThis string...
      if((position = filterThis.indexOf("@")) != -1) {
         // Interpret the part of the string before the at-sign
         // as the element name
         filterThisElement = filterThis.substring(0, position);

         // Interpret the part of the string after the at-sign
         // as the attribute name
         filterThisAttribute = filterThis.substring(position+1);
      }
      else { // There's not a at-sign in the filterThis string
         filterThisElement = filterThis;
      }
   }
   public void characters(char[] chars, int start, int length)
               throws SAXException {
      // If we're not filtering, pass on the event
      if(!filtering)
         super.characters(chars, start, length);
   }
   public void startElement(String uri, String localName,
                            String qName, Attributes attrs) 
                            throws SAXException {
      // If this element matches the element we need to filter...
      if(localName.equals(filterThisElement)) {
         // If an attribute was specified...
         if(filterThisAttribute != null) {
            // Loop over attributes looking for a match...
            for(int i=0; i < attrs.getLength(); ++i) { 
               // If this attribute matches the attribute we're
               // supposed to filter...
               if(attrs.getValue(i).equals(filterThisAttribute)) {
                  // Set filtering to true and break out of loop
                  filtering = true;
                  break;
               }
            }
         }
         else { // If no attribute was specified
            filtering = true;
         }
      }

      // If we're not filtering this element, pass on the
      // event
      if(!filtering)
         super.startElement(uri, localName, qName, attrs);
   }
   public void endElement(String uri, String localName,
                            String qName)
                            throws SAXException {
      // If we're not filtering, pass on the event
      if(filtering == false)
         super.endElement(uri, localName, qName);

      // If we're filtering, stop
      if(filtering)
         filtering = false;
   }
}
