package tags;

import java.util.*;
import javax.servlet.jsp.JspException;
import javax.servlet.jsp.JspTagException;
import javax.servlet.jsp.jstl.core.LoopTagSupport;

public class ShowRequestParametersAction extends LoopTagSupport {
   private Iterator entriesIterator;
   private StringBuffer nextItem = new StringBuffer();

   // Prepare for the next round of the iteration. The prepare 
   // method is invoked once by LoopTagSupport.doStartTag()
   protected void prepare() throws JspTagException {
      // Get a reference to the map of request parameters
      Map parameterMap=pageContext.getRequest().getParameterMap();

      // Store the iterator from the request parameters map
      entriesIterator = parameterMap.entrySet().iterator();
   }

   // Determine whether there are any items left to iterate over
   protected boolean hasNext() throws JspTagException {
      return entriesIterator.hasNext();
   }

   // Return the next item in the collection
   protected Object next() throws JspTagException {
      // Get a reference to the next Map.Entry from the iterator
      // and get that entry's key and value.
      Map.Entry entry = (Map.Entry)entriesIterator.next();
      String      key = (String)entry.getKey();
      String[] values = (String[])entry.getValue();

      // Clear the nextItem string buffer
      nextItem.delete(0, nextItem.length());

      // Add the map entry's key (which is the name of the request
      // parameter) to the nextItem string buffer
      nextItem.append(key + " = ");

      // Iterate over the map entry's value, which is an array of
      // strings representing the current request parameter's
      // values
      for(int i=0; i < values.length; ++i) {
         // Append the current value to the nextItem string buffer
         nextItem.append(values[i]);

         // If it's not the last value, append a comma to the
         // nextItem string buffer
         if(i != values.length-1)
            nextItem.append(",");
      }

      // Create a string from the nextItem string buffer and
      // return that string
      return nextItem.toString();
   }
}
