<%--  This handy JSTL component creates an HTML select 
      element that retains its value if its page is reloaded.

      This component can be passed the following request 
      parameters:

      selectName:    The name of the select element
      items:         The option values
      formatValue:   How option values should be formatted 
      formatDisplay: How option display values should be formatted 

      The items parameter must be a comma-separated string, and
      the formatValue and formatDisplay parameters must be one
      of the following: number, percent, or currency.

      Here's an example of how you'd use this component:

      <form>
         <table>
            <tr>
               <td>Select a value:</td>
               <td>
                  <c:import url='create_html_select.jsp'>
                     <c:param name='selectName' value='amount'/>
                     <c:param name='items'      value='1,2,3,4,5'/>

                     <c:param name='formatValue' 
                             value='currency'/>

                     <c:param name='formatDisplay'
                             value='currency'/>
                  </c:import>
               </td>
            </tr>
         </table>
         <p><input type='submit'/>
      </form>

      The preceding code creates an HTML select element with
      the values 1-5. Those values are formatted as currency, so
      they look like this for the US English locale: $1.00,
      $2.00, ... $5.00.
--%>

<%@ taglib uri='http://java.sun.com/jstl/core' prefix='c'  %>
<%@ taglib uri='http://java.sun.com/jstl/fmt'  prefix='fmt'%>

<%-- Set a page-scoped variable representing the last value
     selected for the HTML select element generated by this
     component --%>
<c:set var='lastValue' value='${param[param.selectName]}'/>

<%-- Create the HTML select element --%>
<select name='<c:out value="${param.selectName}"/>'>
   <c:forEach var='item' items='${param.items}'> 
      <%-- Start the option starting tag --%>
      <option

      <%-- If this item was the last item selected, add the
           string selected to the option starting tag --%>
      <c:if test='${item == lastValue}'>
         selected
      </c:if>

      <%-- If the option's value should be formatted, format 
           it with the formatting type (number, percent, or 
           currency) specified with the format parameter --%>
      <c:choose>
         <c:when test='${not empty param.formatValue == true}'>
            <fmt:formatNumber var='value' value='${item}' 
                             type='${param.formatValue}'/>
               <c:out escapeXml='false' value='value=${value}'/>
         </c:when>

         <c:otherwise>
            value='<c:out value="${item}"/>'
         </c:otherwise>
      </c:choose>

      <%-- Close off the <option> starting tag --%>
      >

      <%-- If the option's display value should be formatted, 
           format it with the formatting type (number, percent, 
           or currency) specified with the format parameter --%>
      <c:choose>
         <c:when test='${not empty param.formatDisplay}'>
            <fmt:formatNumber var='value' value='${item}' 
                             type='${param.formatDisplay}'/>
            <c:out value='${value}'/>
         </c:when>

         <c:otherwise>
            <c:out value='${item}'/>
         </c:otherwise>
      </c:choose>

      <%-- Add the <option> end tag --%>
      </option>
   </c:forEach>
</select>
