import java.io.IOException;
import java.util.Vector;

import javax.servlet.*;
import javax.servlet.http.*;

import beans.ValidationError;

public class ValidationServlet extends HttpServlet {
   public void doGet(HttpServletRequest req,
                     HttpServletResponse res)
                     throws IOException, ServletException {
      // Obtain a reference to the application
      ServletContext app = getServletContext();

      // Use the application to get the value of the 
      // initialization parameter that specifies the bundle 
      // basename
      String bundleBasename = 
           app.getInitParameter("app.validation.bundle.basename");

      // Validate the form data
      boolean errorDetected = validate(req, bundleBasename, 
                                req.getParameter("firstName"),
                                req.getParameter("lastName"),
                                req.getParameter("emailAddress"));

      // If the form data was invalid ...
      if(errorDetected) {
         // Retrieve the failure page from a session attribute
         String page = (String)req.getSession().
                        getAttribute("failurePage");

         // Forward to the failure page
         RequestDispatcher rd = app.getRequestDispatcher(page);
         rd.forward(req, res);
      }
      // If the form data was valid ...
      else {
         // Retrieve the success page from a session attribute
         String page = (String)req.getSession().
                        getAttribute("successPage");

         // Forward to the success page
         RequestDispatcher rd = app.getRequestDispatcher(page);
         rd.forward(req, res);
      }
   }
   private boolean validate(HttpServletRequest req, 
                            String bundleBasename, String first, 
                            String last, String email){
      boolean errorDetected = false;
      Vector errorKeys = new Vector();

      // If any of the fields were not filled in ...
      if(first.equals("") || last.equals("") || email.equals("")){
         errorKeys.add("login.fill-in-all-fields");
         errorDetected = true; 
      }
      // If email address is invalid ...
      if(email.indexOf("@") == -1 || 
        (!email.endsWith(".com") && !email.endsWith(".edu"))) {
         errorKeys.add("login.bad-email-address");
         errorDetected = true;
      }
      // If the form parameters were invalid ...
      if(errorDetected) {
         // Add message indicating invalid parameters
         errorKeys.add(0, "login.error-detected");

         // Store the validation error in a request attribute
         req.setAttribute("validateError", 
                  new ValidationError(bundleBasename, errorKeys));   
      }
      return errorDetected;
   }
}
