<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN">
<html>
   <head>
      <title>Scrolling Through Database Queries</title>
   </head>

   <body>
      <%@ taglib uri='http://java.sun.com/jstl/core' prefix='c' %>
      <%@ taglib uri='http://java.sun.com/jstl/sql'  prefix='sql'%>

      <c:choose>
         <%-- When there is no scroll request parameter --%>
         <c:when test='${empty param.scroll}'> 
            <%-- This query is executed solely to ascertain the 
                 number of customers in the database, which is
                 used to set the scrollMax attribute below --%>
            <sql:query var='exploring'> 
               SELECT * FROM CUSTOMERS   
            </sql:query>

            <%-- Set scrollMax to the number of rows in the 
                 Customers table --%>
            <c:set var='scrollMax' 
                value='${exploring.rowCount}'
                scope='session'/>

            <%-- Set scrollStart to 0 and scrollInc to the value
                 of the request parameter scrollIncrement --%>
            <c:set var='scrollStart' 
                 value='0' scope='session'/>
            <c:set var='scrollInc' value='${param.scrollIncrement}'
                 scope='session'/>
         </c:when>

         <%-- When the scroll request parameter is forward --%>
         <c:when test='${param.scroll == "forward"}'>
            <%-- If it's valid to increment scrollStart --%>
            <c:if test='${scrollStart + scrollInc < scrollMax}'>
               <%-- Increment scrollStart by scrollInc --%>
               <c:set var='scrollStart' 
                    value='${scrollStart + scrollInc}' 
                    scope='session'/>
            </c:if>
         </c:when>

         <%-- When the scroll request parameter is backward --%>
         <c:when test='${param.scroll == "backward"}'>
            <%-- If it's valid to decrement scrollStart --%>
            <c:if test='${scrollStart - scrollInc >= 0}'>
               <%-- Decrement scrollStart by scrollInc --%>
               <c:set var='scrollStart' 
                    value='${scrollStart - scrollInc}' 
                    scope='session'/>
            </c:if>
         </c:when>
      </c:choose>

      <%-- Perform a customer query limited by the scrollStart and
           scrollInc variables --%>
      <sql:query var='customers' startRow='${scrollStart}' 
                                  maxRows='${scrollInc}'>
         SELECT * FROM CUSTOMERS   
         ORDER BY CUST_ID
      </sql:query>

      <%-- Create a table with column names and row data --%>
      <p><table border='1'>
         <tr>
            <c:forEach var='columnName' 
                     items='${customers.columnNames}'>
               <th><c:out value='${columnName}'/></th>
            </c:forEach>
         </tr>
         
         <c:forEach var='row' items='${customers.rowsByIndex}'>
             <tr>
               <c:forEach var='rowData' items='${row}'>
                  <td><c:out value='${rowData}'/></td>
               </c:forEach>
             </tr>
         </c:forEach>
      </table>

      <%-- Create anchors that point back to this page with a
           request parameter indicating scroll direction --%>
      <p>
      <a href='?scroll=forward'>Scroll Forward</a><br>
      <a href='?scroll=backward'>Scroll Backward</a>

      <%-- Show the values of the scrollStart, scrollInc, and
           scrollMax session attributes --%>
      <p><c:out value='Scroll Start: ${scrollStart}'/>, 
         <c:out value='Scroll Inc:   ${scrollInc}'/>,
         <c:out value='Scroll Max:   ${scrollMax}'/><br>
   </body>
</html>
